@@ -1,28 +1,39 @@
 use std::borrow::Cow;
 use std::fmt::Write as _;
-use std::io;
 use std::io::Write as _;
 use std::path::{Path, PathBuf};
+use std::str::FromStr;
+use std::{fmt, io};
 
-use anyhow::Result;
-
+use anyhow::{Context, Result};
 use owo_colors::OwoColorize;
-use tracing::{debug, instrument, trace};
-use uv_distribution_filename::SourceDistExtension;
-use uv_distribution_types::{DependencyMetadata, Index, IndexLocations, SourceDist};
-use uv_install_wheel::linker::LinkMode;
+use thiserror::Error;
+use tracing::instrument;
 
+use crate::commands::pip::operations;
+use crate::commands::project::find_requires_python;
+use crate::commands::reporters::PythonDownloadReporter;
+use crate::commands::ExitStatus;
+use crate::printer::Printer;
+use crate::settings::{ResolverSettings, ResolverSettingsRef};
 use uv_auth::store_credentials;
-use uv_build_backend::PyProjectToml;
+use uv_build_backend::check_direct_build;
 use uv_cache::{Cache, CacheBucket};
 use uv_client::{BaseClientBuilder, Connectivity, FlatIndexClient, RegistryClientBuilder};
 use uv_configuration::{
     BuildKind, BuildOptions, BuildOutput, Concurrency, ConfigSettings, Constraints,
-    HashCheckingMode, IndexStrategy, KeyringProviderType, LowerBound, SourceStrategy, TrustedHost,
+    HashCheckingMode, IndexStrategy, KeyringProviderType, LowerBound, PreviewMode, SourceStrategy,
+    TrustedHost,
 };
 use uv_dispatch::{BuildDispatch, SharedState};
-use uv_fs::Simplified;
+use uv_distribution_filename::{
+    DistFilename, SourceDistExtension, SourceDistFilename, WheelFilename,
+};
+use uv_distribution_types::{DependencyMetadata, Index, IndexLocations, SourceDist};
+use uv_fs::{relative_to, Simplified};
+use uv_install_wheel::linker::LinkMode;
 use uv_normalize::PackageName;
+use uv_pep440::Version;
 use uv_python::{
     EnvironmentPreference, PythonDownloads, PythonEnvironment, PythonInstallation,
     PythonPreference, PythonRequest, PythonVariant, PythonVersionFile, VersionFileDiscoveryOptions,
@@ -34,12 +45,48 @@ use uv_settings::PythonInstallMirrors;
 use uv_types::{BuildContext, BuildIsolation, HashStrategy};
 use uv_workspace::{DiscoveryOptions, Workspace, WorkspaceError};
 
-use crate::commands::pip::operations;
-use crate::commands::project::find_requires_python;
-use crate::commands::reporters::PythonDownloadReporter;
-use crate::commands::ExitStatus;
-use crate::printer::Printer;
-use crate::settings::{ResolverSettings, ResolverSettingsRef};
+#[derive(Debug, Error)]
+enum Error {
+    #[error(transparent)]
+    Io(#[from] io::Error),
+    #[error(transparent)]
+    FindOrDownloadPython(#[from] uv_python::Error),
+    #[error(transparent)]
+    HashStrategy(#[from] uv_types::HashStrategyError),
+    #[error(transparent)]
+    FlatIndex(#[from] uv_client::FlatIndexError),
+    #[error(transparent)]
+    BuildPlan(anyhow::Error),
+    #[error(transparent)]
+    Extract(#[from] uv_extract::Error),
+    #[error(transparent)]
+    Operations(#[from] operations::Error),
+    #[error(transparent)]
+    Join(#[from] tokio::task::JoinError),
+    #[error(transparent)]
+    BuildBackend(#[from] uv_build_backend::Error),
+    #[error(transparent)]
+    BuildDispatch(anyhow::Error),
+    #[error(transparent)]
+    BuildFrontend(#[from] uv_build_frontend::Error),
+    #[error("Failed to write message")]
+    Fmt(#[from] fmt::Error),
+    #[error("Can't use `--force-pep517` with `--list`")]
+    ListForcePep517,
+    #[error("Can only use `--list` with the uv backend")]
+    ListNonUv,
+    #[error(
+        "`{0}` is not a valid build source. Expected to receive a source directory, or a source \
+         distribution ending in one of: {1}."
+    )]
+    InvalidSourceDistExt(String, uv_distribution_filename::ExtensionError),
+    #[error("The built source distribution has an invalid filename")]
+    InvalidBuiltSourceDistFilename(#[source] uv_distribution_filename::SourceDistFilenameError),
+    #[error("The built wheel has an invalid filename")]
+    InvalidBuiltWheelFilename(#[source] uv_distribution_filename::WheelFilenameError),
+    #[error("The source distribution declares version {0}, but the wheel declares version {1}")]
+    VersionMismatch(Version, Version),
+}
 
 /// Build source distributions and wheels.
 #[allow(clippy::fn_params_excessive_bools)]
@@ -51,6 +98,7 @@ pub(crate) async fn build_frontend(
     output_dir: Option<PathBuf>,
     sdist: bool,
     wheel: bool,
+    list: bool,
     build_logs: bool,
     force_pep517: bool,
     build_constraints: Vec<RequirementsSource>,
@@ -67,6 +115,7 @@ pub(crate) async fn build_frontend(
     allow_insecure_host: &[TrustedHost],
     cache: &Cache,
     printer: Printer,
+    preview: PreviewMode,
 ) -> Result<ExitStatus> {
     let build_result = build_impl(
         project_dir,
@@ -76,6 +125,7 @@ pub(crate) async fn build_frontend(
         output_dir.as_deref(),
         sdist,
         wheel,
+        list,
         build_logs,
         force_pep517,
         &build_constraints,
@@ -92,6 +142,7 @@ pub(crate) async fn build_frontend(
         allow_insecure_host,
         cache,
         printer,
+        preview,
     )
     .await?;
 
@@ -119,6 +170,7 @@ async fn build_impl(
     output_dir: Option<&Path>,
     sdist: bool,
     wheel: bool,
+    list: bool,
     build_logs: bool,
     force_pep517: bool,
     build_constraints: &[RequirementsSource],
@@ -135,7 +187,17 @@ async fn build_impl(
     allow_insecure_host: &[TrustedHost],
     cache: &Cache,
     printer: Printer,
+    preview: PreviewMode,
 ) -> Result<BuildResult> {
+    if list && preview.is_disabled() {
+        // We need the direct build for list and that is preview only.
+        writeln!(
+            printer.stderr(),
+            "The `--list` option is only available in preview mode; add the `--preview` flag to use `--list`"
+        )?;
+        return Ok(BuildResult::Failure);
+    }
+
     // Extract the resolver settings.
     let ResolverSettingsRef {
         index_locations,
@@ -286,9 +348,11 @@ async fn build_impl(
             build_options,
             sdist,
             wheel,
+            list,
             dependency_metadata,
             link_mode,
             config_setting,
+            preview,
         );
         async {
             let result = future.await;
@@ -300,30 +364,11 @@ async fn build_impl(
     let mut success = true;
     for (source, result) in results {
         match result {
-            Ok(assets) => match assets {
-                BuiltDistributions::Wheel(wheel) => {
-                    writeln!(
-                        printer.stderr(),
-                        "Successfully built {}",
-                        wheel.user_display().bold().cyan()
-                    )?;
+            Ok(messages) => {
+                for message in messages {
+                    message.print(printer)?;
                 }
-                BuiltDistributions::Sdist(sdist) => {
-                    writeln!(
-                        printer.stderr(),
-                        "Successfully built {}",
-                        sdist.user_display().bold().cyan()
-                    )?;
-                }
-                BuiltDistributions::Both(sdist, wheel) => {
-                    writeln!(
-                        printer.stderr(),
-                        "Successfully built {} and {}",
-                        sdist.user_display().bold().cyan(),
-                        wheel.user_display().bold().cyan()
-                    )?;
-                }
-            },
+            }
             Err(err) => {
                 #[derive(Debug, miette::Diagnostic, thiserror::Error)]
                 #[error("Failed to build `{source}`", source = source.cyan())]
@@ -336,7 +381,7 @@ async fn build_impl(
 
                 let report = miette::Report::new(Diagnostic {
                     source: source.to_string(),
-                    cause: err,
+                    cause: err.into(),
                 });
                 anstream::eprint!("{report:?}");
 
@@ -383,10 +428,12 @@ async fn build_package(
     build_options: &BuildOptions,
     sdist: bool,
     wheel: bool,
+    list: bool,
     dependency_metadata: &DependencyMetadata,
     link_mode: LinkMode,
     config_setting: &ConfigSettings,
-) -> Result<BuiltDistributions> {
+    preview: PreviewMode,
+) -> Result<Vec<BuildMessage>, Error> {
     let output_dir = if let Some(output_dir) = output_dir {
         Cow::Owned(std::path::absolute(output_dir)?)
     } else {
@@ -529,16 +576,35 @@ async fn build_package(
         LowerBound::Allow,
         sources,
         concurrency,
+        preview,
     );
 
     prepare_output_directory(&output_dir).await?;
 
     // Determine the build plan.
-    let plan = BuildPlan::determine(&source, sdist, wheel)?;
+    let plan = BuildPlan::determine(&source, sdist, wheel).map_err(Error::BuildPlan)?;
 
     // Check if the build backend is matching uv version that allows calling in the uv build backend
     // directly.
-    let fast_path = !force_pep517 && check_fast_path(source.path());
+    let build_action = if list {
+        if force_pep517 {
+            return Err(Error::ListForcePep517);
+        }
+
+        if !check_direct_build(source.path(), source.path().user_display()) {
+            // TODO(konsti): Provide more context on what mismatched
+            return Err(Error::ListNonUv);
+        }
+
+        BuildAction::List
+    } else if preview.is_enabled()
+        && !force_pep517
+        && check_direct_build(source.path(), source.path().user_display())
+    {
+        BuildAction::DirectBuild
+    } else {
+        BuildAction::Pep517
+    };
 
     // Prepare some common arguments for the build.
     let dist = None;
@@ -556,15 +622,36 @@ async fn build_package(
         Printer::Quiet => BuildOutput::Quiet,
     };
 
-    let assets = match plan {
+    let mut build_results = Vec::new();
+    match plan {
         BuildPlan::SdistToWheel => {
-            let sdist = build_sdist(
+            // Even when listing files, we still need to build the source distribution for the wheel
+            // build.
+            if list {
+                let sdist_list = build_sdist(
+                    source.path(),
+                    &output_dir,
+                    build_action,
+                    &source,
+                    printer,
+                    "source distribution",
+                    &build_dispatch,
+                    sources,
+                    dist,
+                    subdirectory,
+                    version_id,
+                    build_output,
+                )
+                .await?;
+                build_results.push(sdist_list);
+            }
+            let sdist_build = build_sdist(
                 source.path(),
                 &output_dir,
-                fast_path,
+                build_action.force_build(),
                 &source,
                 printer,
-                "Building source distribution",
+                "source distribution",
                 &build_dispatch,
                 sources,
                 dist,
@@ -573,13 +660,13 @@ async fn build_package(
                 build_output,
             )
             .await?;
+            build_results.push(sdist_build.clone());
 
             // Extract the source distribution into a temporary directory.
-            let path = output_dir.join(&sdist);
+            let path = output_dir.join(sdist_build.filename().to_string());
             let reader = fs_err::tokio::File::open(&path).await?;
-            let ext = SourceDistExtension::from_path(path.as_path()).map_err(|err| {
-                anyhow::anyhow!("`{}` is not a valid source distribution, as it ends with an unsupported extension. Expected one of: {err}.", path.user_display())
-            })?;
+            let ext = SourceDistExtension::from_path(path.as_path())
+                .map_err(|err| Error::InvalidSourceDistExt(path.user_display().to_string(), err))?;
             let temp_dir = tempfile::tempdir_in(cache.bucket(CacheBucket::SourceDistributions))?;
             uv_extract::stream::archive(reader, ext, temp_dir.path()).await?;
 
@@ -590,32 +677,32 @@ async fn build_package(
                 Err(err) => return Err(err.into()),
             };
 
-            let wheel = build_wheel(
+            let wheel_build = build_wheel(
                 &extracted,
                 &output_dir,
-                fast_path,
+                build_action,
                 &source,
                 printer,
-                "Building wheel from source distribution",
+                "wheel from source distribution",
                 &build_dispatch,
                 sources,
                 dist,
                 subdirectory,
                 version_id,
                 build_output,
+                Some(sdist_build.filename().version()),
             )
             .await?;
-
-            BuiltDistributions::Both(output_dir.join(sdist), output_dir.join(wheel))
+            build_results.push(wheel_build);
         }
         BuildPlan::Sdist => {
-            let sdist = build_sdist(
+            let sdist_build = build_sdist(
                 source.path(),
                 &output_dir,
-                fast_path,
+                build_action,
                 &source,
                 printer,
-                "Building source distribution",
+                "source distribution",
                 &build_dispatch,
                 sources,
                 dist,
@@ -624,36 +711,35 @@ async fn build_package(
                 build_output,
             )
             .await?;
-
-            BuiltDistributions::Sdist(output_dir.join(sdist))
+            build_results.push(sdist_build);
         }
         BuildPlan::Wheel => {
-            let wheel = build_wheel(
+            let wheel_build = build_wheel(
                 source.path(),
                 &output_dir,
-                fast_path,
+                build_action,
                 &source,
                 printer,
-                "Building wheel",
+                "wheel",
                 &build_dispatch,
                 sources,
                 dist,
                 subdirectory,
                 version_id,
                 build_output,
+                None,
             )
             .await?;
-
-            BuiltDistributions::Wheel(output_dir.join(wheel))
+            build_results.push(wheel_build);
         }
         BuildPlan::SdistAndWheel => {
-            let sdist = build_sdist(
+            let sdist_build = build_sdist(
                 source.path(),
                 &output_dir,
-                fast_path,
+                build_action,
                 &source,
                 printer,
-                "Building source distribution",
+                "source distribution",
                 &build_dispatch,
                 sources,
                 dist,
@@ -663,36 +749,42 @@ async fn build_package(
             )
             .await?;
 
-            let wheel = build_wheel(
+            let wheel_build = build_wheel(
                 source.path(),
                 &output_dir,
-                fast_path,
+                build_action,
                 &source,
                 printer,
-                "Building wheel",
+                "wheel",
                 &build_dispatch,
                 sources,
                 dist,
                 subdirectory,
                 version_id,
                 build_output,
+                Some(sdist_build.filename().version()),
             )
             .await?;
-
-            BuiltDistributions::Both(output_dir.join(&sdist), output_dir.join(&wheel))
+            build_results.push(sdist_build);
+            build_results.push(wheel_build);
         }
         BuildPlan::WheelFromSdist => {
             // Extract the source distribution into a temporary directory.
             let reader = fs_err::tokio::File::open(source.path()).await?;
             let ext = SourceDistExtension::from_path(source.path()).map_err(|err| {
-                anyhow::anyhow!(
-                    "`{}` is not a valid build source. Expected to receive a source directory, or a source distribution ending in one of: {err}.",
-                    source.path().user_display()
-                )
+                Error::InvalidSourceDistExt(source.path().user_display().to_string(), err)
             })?;
             let temp_dir = tempfile::tempdir_in(&output_dir)?;
             uv_extract::stream::archive(reader, ext, temp_dir.path()).await?;
 
+            // If the source distribution has a version in its filename, check the version.
+            let version = source
+                .path()
+                .file_name()
+                .and_then(|filename| filename.to_str())
+                .and_then(|filename| SourceDistFilename::parsed_normalized_filename(filename).ok())
+                .map(|filename| filename.version);
+
             // Extract the top-level directory from the archive.
             let extracted = match uv_extract::strip_component(temp_dir.path()) {
                 Ok(top_level) => top_level,
@@ -700,38 +792,60 @@ async fn build_package(
                 Err(err) => return Err(err.into()),
             };
 
-            let wheel = build_wheel(
+            let wheel_build = build_wheel(
                 &extracted,
                 &output_dir,
-                fast_path,
+                build_action,
                 &source,
                 printer,
-                "Building wheel from source distribution",
+                "wheel from source distribution",
                 &build_dispatch,
                 sources,
                 dist,
                 subdirectory,
                 version_id,
                 build_output,
+                version.as_ref(),
             )
             .await?;
-
-            BuiltDistributions::Wheel(output_dir.join(wheel))
+            build_results.push(wheel_build);
         }
-    };
+    }
 
-    Ok(assets)
+    Ok(build_results)
 }
 
-/// Build a source distribution, either through PEP 517 or through the fast path.
+#[derive(Copy, Clone, PartialEq, Eq)]
+enum BuildAction {
+    /// Only list the files that would be included, don't actually build.
+    List,
+    /// Build by calling directly into the build backend.
+    DirectBuild,
+    /// Build through the PEP 517 hooks.
+    Pep517,
+}
+
+impl BuildAction {
+    /// If in list mode, still build the distribution.
+    fn force_build(self) -> Self {
+        match self {
+            // List is only available for the uv build backend
+            Self::List => Self::DirectBuild,
+            Self::DirectBuild => Self::DirectBuild,
+            Self::Pep517 => Self::Pep517,
+        }
+    }
+}
+
+/// Build a source distribution, either through PEP 517 or through a direct build.
 #[instrument(skip_all)]
 async fn build_sdist(
     source_tree: &Path,
     output_dir: &Path,
-    fast_path: bool,
+    action: BuildAction,
     source: &AnnotatedSource<'_>,
     printer: Printer,
-    message: &str,
+    build_kind_message: &str,
     // Below is only used with PEP 517 builds
     build_dispatch: &BuildDispatch<'_>,
     sources: SourceStrategy,
@@ -739,57 +853,98 @@ async fn build_sdist(
     subdirectory: Option<&Path>,
     version_id: Option<&str>,
     build_output: BuildOutput,
-) -> Result<String> {
-    let sdist = if fast_path {
-        writeln!(
-            printer.stderr(),
-            "{}",
-            format!(
-                "{}{} (uv build backend)...",
-                source.message_prefix(),
-                message
-            )
-            .bold()
-        )?;
-        let source_tree = source_tree.to_path_buf();
-        let output_dir = output_dir.to_path_buf();
-        tokio::task::spawn_blocking(move || {
-            uv_build_backend::build_source_dist(&source_tree, &output_dir, uv_version::version())
-        })
-        .await??
-        .to_string()
-    } else {
-        writeln!(
-            printer.stderr(),
-            "{}",
-            format!("{}{}...", source.message_prefix(), message).bold()
-        )?;
-        let builder = build_dispatch
-            .setup_build(
-                source_tree,
-                subdirectory,
-                source.path(),
-                version_id.map(ToString::to_string),
-                dist,
-                sources,
-                BuildKind::Sdist,
-                build_output,
-            )
-            .await?;
-        builder.build(output_dir).await?
+) -> Result<BuildMessage, Error> {
+    let build_result = match action {
+        BuildAction::List => {
+            let source_tree_ = source_tree.to_path_buf();
+            let (filename, file_list) = tokio::task::spawn_blocking(move || {
+                uv_build_backend::list_source_dist(&source_tree_, uv_version::version())
+            })
+            .await??;
+
+            BuildMessage::List {
+                filename: DistFilename::SourceDistFilename(filename),
+                source_tree: source_tree.to_path_buf(),
+                file_list,
+            }
+        }
+        BuildAction::DirectBuild => {
+            writeln!(
+                printer.stderr(),
+                "{}",
+                format!(
+                    "{}Building {} (uv build backend)...",
+                    source.message_prefix(),
+                    build_kind_message
+                )
+                .bold()
+            )?;
+            let source_tree = source_tree.to_path_buf();
+            let output_dir_ = output_dir.to_path_buf();
+            let filename = tokio::task::spawn_blocking(move || {
+                uv_build_backend::build_source_dist(
+                    &source_tree,
+                    &output_dir_,
+                    uv_version::version(),
+                )
+            })
+            .await??
+            .to_string();
+
+            BuildMessage::Build {
+                filename: DistFilename::SourceDistFilename(
+                    SourceDistFilename::parsed_normalized_filename(&filename)
+                        .map_err(Error::InvalidBuiltSourceDistFilename)?,
+                ),
+                output_dir: output_dir.to_path_buf(),
+            }
+        }
+        BuildAction::Pep517 => {
+            writeln!(
+                printer.stderr(),
+                "{}",
+                format!(
+                    "{}Building {}...",
+                    source.message_prefix(),
+                    build_kind_message
+                )
+                .bold()
+            )?;
+            let builder = build_dispatch
+                .setup_build(
+                    source_tree,
+                    subdirectory,
+                    source.path(),
+                    version_id,
+                    dist,
+                    sources,
+                    BuildKind::Sdist,
+                    build_output,
+                )
+                .await
+                .map_err(Error::BuildDispatch)?;
+            let filename = builder.build(output_dir).await?;
+            BuildMessage::Build {
+                filename: DistFilename::SourceDistFilename(
+                    SourceDistFilename::parsed_normalized_filename(&filename)
+                        .map_err(Error::InvalidBuiltSourceDistFilename)?,
+                ),
+                output_dir: output_dir.to_path_buf(),
+            }
+        }
     };
-    Ok(sdist)
+    Ok(build_result)
 }
 
-/// Build a wheel, either through PEP 517 or through the fast path.
+/// Build a wheel, either through PEP 517 or through a direct build.
 #[instrument(skip_all)]
 async fn build_wheel(
     source_tree: &Path,
     output_dir: &Path,
-    fast_path: bool,
+    action: BuildAction,
     source: &AnnotatedSource<'_>,
     printer: Printer,
-    message: &str,
+    build_kind_message: &str,
     // Below is only used with PEP 517 builds
     build_dispatch: &BuildDispatch<'_>,
     sources: SourceStrategy,
@@ -797,50 +952,94 @@ async fn build_wheel(
     subdirectory: Option<&Path>,
     version_id: Option<&str>,
     build_output: BuildOutput,
-) -> Result<String> {
-    let wheel = if fast_path {
-        writeln!(
-            printer.stderr(),
-            "{}",
-            format!(
-                "{}{} (uv build backend)...",
-                source.message_prefix(),
-                message
-            )
-            .bold()
-        )?;
-        let source_tree = source_tree.to_path_buf();
-        let output_dir = output_dir.to_path_buf();
-        tokio::task::spawn_blocking(move || {
-            uv_build_backend::build_wheel(&source_tree, &output_dir, None, uv_version::version())
-        })
-        .await??
-        .to_string()
-    } else {
-        writeln!(
-            printer.stderr(),
-            "{}",
-            format!("{}{}...", source.message_prefix(), message).bold()
-        )?;
-        let builder = build_dispatch
-            .setup_build(
-                source_tree,
-                subdirectory,
-                source.path(),
-                version_id.map(ToString::to_string),
-                dist,
-                sources,
-                BuildKind::Wheel,
-                build_output,
-            )
-            .await?;
-        builder.build(output_dir).await?
+    // Used for checking version consistency
+    version: Option<&Version>,
+) -> Result<BuildMessage, Error> {
+    let build_message = match action {
+        BuildAction::List => {
+            let source_tree_ = source_tree.to_path_buf();
+            let (filename, file_list) = tokio::task::spawn_blocking(move || {
+                uv_build_backend::list_wheel(&source_tree_, uv_version::version())
+            })
+            .await??;
+            BuildMessage::List {
+                filename: DistFilename::WheelFilename(filename),
+                source_tree: source_tree.to_path_buf(),
+                file_list,
+            }
+        }
+        BuildAction::DirectBuild => {
+            writeln!(
+                printer.stderr(),
+                "{}",
+                format!(
+                    "{}Building {} (uv build backend)...",
+                    source.message_prefix(),
+                    build_kind_message
+                )
+                .bold()
+            )?;
+            let source_tree = source_tree.to_path_buf();
+            let output_dir_ = output_dir.to_path_buf();
+            let filename = tokio::task::spawn_blocking(move || {
+                uv_build_backend::build_wheel(
+                    &source_tree,
+                    &output_dir_,
+                    None,
+                    uv_version::version(),
+                )
+            })
+            .await??;
+
+            BuildMessage::Build {
+                filename: DistFilename::WheelFilename(filename),
+                output_dir: output_dir.to_path_buf(),
+            }
+        }
+        BuildAction::Pep517 => {
+            writeln!(
+                printer.stderr(),
+                "{}",
+                format!(
+                    "{}Building {}...",
+                    source.message_prefix(),
+                    build_kind_message
+                )
+                .bold()
+            )?;
+            let builder = build_dispatch
+                .setup_build(
+                    source_tree,
+                    subdirectory,
+                    source.path(),
+                    version_id,
+                    dist,
+                    sources,
+                    BuildKind::Wheel,
+                    build_output,
+                )
+                .await
+                .map_err(Error::BuildDispatch)?;
+            let filename = builder.build(output_dir).await?;
+            BuildMessage::Build {
+                filename: DistFilename::WheelFilename(
+                    WheelFilename::from_str(&filename).map_err(Error::InvalidBuiltWheelFilename)?,
+                ),
+                output_dir: output_dir.to_path_buf(),
+            }
+        }
     };
-    Ok(wheel)
+    if let Some(expected) = version {
+        let actual = build_message.filename().version();
+        if expected != actual {
+            return Err(Error::VersionMismatch(expected.clone(), actual.clone()));
+        }
+    }
+    Ok(build_message)
 }
 
 /// Create the output directory and add a `.gitignore`.
-async fn prepare_output_directory(output_dir: &Path) -> Result<()> {
+async fn prepare_output_directory(output_dir: &Path) -> Result<(), Error> {
     // Create the output directory.
     fs_err::tokio::create_dir_all(&output_dir).await?;
 
@@ -926,14 +1125,80 @@ impl<'a> Source<'a> {
     }
 }
 
-#[derive(Debug, Clone, PartialEq, Eq)]
-enum BuiltDistributions {
-    /// A built wheel.
-    Wheel(PathBuf),
-    /// A built source distribution.
-    Sdist(PathBuf),
-    /// A built source distribution and wheel.
-    Both(PathBuf, PathBuf),
+/// We run all builds in parallel, so we wait until all builds are done to show the success messages
+/// in order.
+#[derive(Debug, Clone)]
+enum BuildMessage {
+    /// A built wheel or source distribution.
+    Build {
+        /// The name of the built distribution.
+        filename: DistFilename,
+        /// The location of the built distribution.
+        output_dir: PathBuf,
+    },
+    /// Show the list of files that would be included in a distribution.
+    List {
+        /// The name of the build distribution.
+        filename: DistFilename,
+        // All source files are relative to the source tree.
+        source_tree: PathBuf,
+        // Included file and source file, if not generated.
+        file_list: Vec<(String, Option<PathBuf>)>,
+    },
+}
+
+impl BuildMessage {
+    /// The filename of the wheel or source distribution.
+    fn filename(&self) -> &DistFilename {
+        match self {
+            BuildMessage::Build { filename: name, .. } => name,
+            BuildMessage::List { filename: name, .. } => name,
+        }
+    }
+
+    fn print(&self, printer: Printer) -> Result<()> {
+        match self {
+            BuildMessage::Build {
+                filename,
+                output_dir,
+            } => {
+                writeln!(
+                    printer.stderr(),
+                    "Successfully built {}",
+                    output_dir
+                        .join(filename.to_string())
+                        .user_display()
+                        .bold()
+                        .cyan()
+                )?;
+            }
+            BuildMessage::List {
+                filename,
+                file_list,
+                source_tree,
+            } => {
+                writeln!(
+                    printer.stdout(),
+                    "{}",
+                    format!("Building {filename} will include the following files:").bold()
+                )?;
+                for (file, source) in file_list {
+                    if let Some(source) = source {
+                        writeln!(
+                            printer.stdout(),
+                            "{file} ({})",
+                            relative_to(source, source_tree)
+                                .context("Included files must be relative to source tree")?
+                                .display()
+                        )?;
+                    } else {
+                        writeln!(printer.stdout(), "{file} (generated)")?;
+                    }
+                }
+            }
+        }
+        Ok(())
+    }
 }
 
 #[derive(Debug, Copy, Clone, PartialEq, Eq)]
@@ -985,33 +1250,3 @@ impl BuildPlan {
         })
     }
 }
-
-/// Check if the build backend is matching the currently running uv version.
-fn check_fast_path(source_tree: &Path) -> bool {
-    let pyproject_toml: PyProjectToml =
-        match fs_err::read_to_string(source_tree.join("pyproject.toml"))
-            .map_err(anyhow::Error::from)
-            .and_then(|pyproject_toml| Ok(toml::from_str(&pyproject_toml)?))
-        {
-            Ok(pyproject_toml) => pyproject_toml,
-            Err(err) => {
-                debug!("Not using uv build backend fast path, no pyproject.toml: {err}");
-                return false;
-            }
-        };
-    match pyproject_toml
-        .check_build_system(uv_version::version())
-        .as_slice()
-    {
-        // No warnings -> match
-        [] => true,
-        // Any warning -> no match
-        [first, others @ ..] => {
-            debug!("Not using uv build backend fast path, pyproject.toml does not match: {first}");
-            for other in others {
-                trace!("Further uv build backend fast path mismatch: {other}");
-            }
-            false
-        }
-    }
-}
