@@ -8,7 +8,7 @@ use uv_cache::Cache;
 use uv_client::{BaseClientBuilder, Connectivity, FlatIndexClient, RegistryClientBuilder};
 use uv_configuration::{
     BuildOptions, Concurrency, ConfigSettings, Constraints, ExtrasSpecification, HashCheckingMode,
-    IndexStrategy, LowerBound, Reinstall, SourceStrategy, TrustedHost, Upgrade,
+    IndexStrategy, LowerBound, PreviewMode, Reinstall, SourceStrategy, TrustedHost, Upgrade,
 };
 use uv_configuration::{KeyringProviderType, TargetTriple};
 use uv_dispatch::{BuildDispatch, SharedState};
@@ -51,6 +51,7 @@ pub(crate) async fn pip_sync(
     dependency_metadata: DependencyMetadata,
     keyring_provider: KeyringProviderType,
     allow_empty_requirements: bool,
+    installer_metadata: bool,
     connectivity: Connectivity,
     config_settings: &ConfigSettings,
     no_build_isolation: bool,
@@ -73,6 +74,7 @@ pub(crate) async fn pip_sync(
     cache: Cache,
     dry_run: bool,
     printer: Printer,
+    preview: PreviewMode,
 ) -> Result<ExitStatus> {
     let client_builder = BaseClientBuilder::new()
         .connectivity(connectivity)
@@ -305,9 +307,6 @@ pub(crate) async fn pip_sync(
     // When resolving, don't take any external preferences into account.
     let preferences = Vec::default();
 
-    // Ignore development dependencies.
-    let dev = Vec::default();
-
     // Create a build dispatch.
     let build_dispatch = BuildDispatch::new(
         &client,
@@ -328,6 +327,7 @@ pub(crate) async fn pip_sync(
         LowerBound::Warn,
         sources,
         concurrency,
+        preview,
     );
 
     // Determine the set of installed packages.
@@ -345,7 +345,6 @@ pub(crate) async fn pip_sync(
         requirements,
         constraints,
         overrides,
-        dev,
         source_trees,
         project,
         None,
@@ -398,6 +397,7 @@ pub(crate) async fn pip_sync(
         &cache,
         &environment,
         Box::new(DefaultInstallLogger),
+        installer_metadata,
         dry_run,
         printer,
     )
