@@ -9,7 +9,7 @@ use uv_cache::Cache;
 use uv_client::{BaseClientBuilder, Connectivity, FlatIndexClient, RegistryClientBuilder};
 use uv_configuration::{
     Concurrency, Constraints, DevGroupsManifest, DevGroupsSpecification, ExtrasSpecification,
-    GroupsSpecification, LowerBound, Reinstall, TrustedHost, Upgrade,
+    GroupsSpecification, LowerBound, PreviewMode, Reinstall, TrustedHost, Upgrade,
 };
 use uv_dispatch::{BuildDispatch, SharedState};
 use uv_distribution::DistributionDatabase;
@@ -896,6 +896,7 @@ pub(crate) async fn resolve_names(
     allow_insecure_host: &[TrustedHost],
     cache: &Cache,
     printer: Printer,
+    preview: PreviewMode,
 ) -> Result<Vec<Requirement>, uv_requirements::Error> {
     // Partition the requirements into named and unnamed requirements.
     let (mut requirements, unnamed): (Vec<_>, Vec<_>) =
@@ -991,6 +992,7 @@ pub(crate) async fn resolve_names(
         LowerBound::Allow,
         *sources,
         concurrency,
+        preview,
     );
 
     // Resolve the unnamed requirements.
@@ -1045,6 +1047,7 @@ pub(crate) async fn resolve_environment<'a>(
     allow_insecure_host: &[TrustedHost],
     cache: &Cache,
     printer: Printer,
+    preview: PreviewMode,
 ) -> Result<ResolverOutput, ProjectError> {
     warn_on_requirements_txt_setting(&spec.requirements, settings);
 
@@ -1120,7 +1123,6 @@ pub(crate) async fn resolve_environment<'a>(
 
     // TODO(charlie): These are all default values. We should consider whether we want to make them
     // optional on the downstream APIs.
-    let dev = Vec::default();
     let extras = ExtrasSpecification::default();
     let hasher = HashStrategy::default();
     let build_constraints = Constraints::default();
@@ -1173,6 +1175,7 @@ pub(crate) async fn resolve_environment<'a>(
         LowerBound::Allow,
         sources,
         concurrency,
+        preview,
     );
 
     // Resolve the requirements.
@@ -1180,7 +1183,6 @@ pub(crate) async fn resolve_environment<'a>(
         requirements,
         constraints,
         overrides,
-        dev,
         source_trees,
         project,
         None,
@@ -1213,12 +1215,14 @@ pub(crate) async fn sync_environment(
     settings: InstallerSettingsRef<'_>,
     state: &SharedState,
     logger: Box<dyn InstallLogger>,
+    installer_metadata: bool,
     connectivity: Connectivity,
     concurrency: Concurrency,
     native_tls: bool,
     allow_insecure_host: &[TrustedHost],
     cache: &Cache,
     printer: Printer,
+    preview: PreviewMode,
 ) -> Result<PythonEnvironment, ProjectError> {
     let InstallerSettingsRef {
         index_locations,
@@ -1306,6 +1310,7 @@ pub(crate) async fn sync_environment(
         LowerBound::Allow,
         sources,
         concurrency,
+        preview,
     );
 
     // Sync the environment.
@@ -1328,6 +1333,7 @@ pub(crate) async fn sync_environment(
         cache,
         &venv,
         logger,
+        installer_metadata,
         dry_run,
         printer,
     )
@@ -1363,12 +1369,14 @@ pub(crate) async fn update_environment(
     state: &SharedState,
     resolve: Box<dyn ResolveLogger>,
     install: Box<dyn InstallLogger>,
+    installer_metadata: bool,
     connectivity: Connectivity,
     concurrency: Concurrency,
     native_tls: bool,
     allow_insecure_host: &[TrustedHost],
     cache: &Cache,
     printer: Printer,
+    preview: PreviewMode,
 ) -> Result<EnvironmentUpdate, ProjectError> {
     warn_on_requirements_txt_setting(&spec, settings.as_ref().into());
 
@@ -1471,7 +1479,6 @@ pub(crate) async fn update_environment(
     // optional on the downstream APIs.
     let build_constraints = Constraints::default();
     let build_hasher = HashStrategy::default();
-    let dev = Vec::default();
     let dry_run = false;
     let extras = ExtrasSpecification::default();
     let hasher = HashStrategy::default();
@@ -1510,6 +1517,7 @@ pub(crate) async fn update_environment(
         LowerBound::Allow,
         *sources,
         concurrency,
+        preview,
     );
 
     // Resolve the requirements.
@@ -1517,7 +1525,6 @@ pub(crate) async fn update_environment(
         requirements,
         constraints,
         overrides,
-        dev,
         source_trees,
         project,
         None,
@@ -1566,6 +1573,7 @@ pub(crate) async fn update_environment(
         cache,
         &venv,
         install,
+        installer_metadata,
         dry_run,
         printer,
     )
