@@ -18,7 +18,7 @@ use uv_cli::ExternalCommand;
 use uv_client::{BaseClientBuilder, Connectivity};
 use uv_configuration::{
     Concurrency, DevGroupsSpecification, EditableMode, ExtrasSpecification, GroupsSpecification,
-    InstallOptions, LowerBound, SourceStrategy, TrustedHost,
+    InstallOptions, LowerBound, PreviewMode, SourceStrategy, TrustedHost,
 };
 use uv_dispatch::SharedState;
 use uv_distribution::LoweredRequirement;
@@ -77,6 +77,7 @@ pub(crate) async fn run(
     settings: ResolverInstallerSettings,
     python_preference: PythonPreference,
     python_downloads: PythonDownloads,
+    installer_metadata: bool,
     connectivity: Connectivity,
     concurrency: Concurrency,
     native_tls: bool,
@@ -85,6 +86,7 @@ pub(crate) async fn run(
     printer: Printer,
     env_file: Vec<PathBuf>,
     no_env_file: bool,
+    preview: PreviewMode,
 ) -> anyhow::Result<ExitStatus> {
     // These cases seem quite complex because (in theory) they should change the "current package".
     // Let's ban them entirely for now.
@@ -333,12 +335,14 @@ pub(crate) async fn run(
                 } else {
                     Box::new(SummaryInstallLogger)
                 },
+                installer_metadata,
                 connectivity,
                 concurrency,
                 native_tls,
                 allow_insecure_host,
                 cache,
                 printer,
+                preview,
             )
             .await;
 
@@ -660,6 +664,7 @@ pub(crate) async fn run(
                     allow_insecure_host,
                     cache,
                     printer,
+                    preview,
                 )
                 .await
                 {
@@ -733,12 +738,14 @@ pub(crate) async fn run(
                     } else {
                         Box::new(SummaryInstallLogger)
                     },
+                    installer_metadata,
                     connectivity,
                     concurrency,
                     native_tls,
                     allow_insecure_host,
                     cache,
                     printer,
+                    preview,
                 )
                 .await
                 {
@@ -883,12 +890,14 @@ pub(crate) async fn run(
                     } else {
                         Box::new(SummaryInstallLogger)
                     },
+                    installer_metadata,
                     connectivity,
                     concurrency,
                     native_tls,
                     allow_insecure_host,
                     cache,
                     printer,
+                    preview,
                 )
                 .await;
 
