@@ -266,7 +266,7 @@ fn prune_unzipped() -> Result<()> {
           need to be downloaded from a registry, we can conclude that iniconfig<1.0.0 cannot be used.
           And because you require iniconfig, we can conclude that your requirements are unsatisfiable.
 
-          hint: Pre-releases are available for iniconfig in the requested range (e.g., 0.2.dev0), but pre-releases weren't enabled (try: `--prerelease=allow`)
+          hint: Pre-releases are available for `iniconfig` in the requested range (e.g., 0.2.dev0), but pre-releases weren't enabled (try: `--prerelease=allow`)
 
           hint: Packages were unavailable because the network was disabled. When the network is disabled, registry packages may only be read from the cache.
     "###);
